@@ -4,6 +4,8 @@ from .model import Cirilla, Args
 from .modules import benchmark_model_part, load_balancing_loss
 from .tokenizer_modules import CirillaTokenizer
 from .training import TrainingArgs, CirillaTrainer
+from .blocks import Encoder, EncoderArgs, Decoder, DecoderArgs, MLPMixer1D, MixerArgs
+from .trm import CirillaTRM, TRMArgs
 
 __all__ = [
             'CirillaBERT',
@@ -15,5 +17,13 @@ __all__ = [
             'TrainingArgs',
             'CirillaTrainer',
             'benchmark_model_part',
-            'load_balancing_loss'
+            'load_balancing_loss',
+            'Encoder',
+            'EncoderArgs',
+            'Decoder',
+            'DecoderArgs',
+            'CirillaTRM',
+            'TRMArgs',
+            'MLPMixer1D',
+            'MixerArgs'
         ]
